.. include:: /_includes/wip_prolog.rst

:mod:`stix.ttp.exploit` Module
==================================

.. module:: stix.ttp.exploit

Classes
-------

.. autoclass:: Exploit
	:show-inheritance:
	:members:
